@@ -7,7 +7,11 @@ from graphinder.utils.filters import transform_url_in_domain
 from graphinder.utils.logger import get_logger
 
 
-def read_domains(file: TextIOWrapper | None, domain: str | None, precision_mode: bool = False) -> list[Domain]:
+def read_domains(
+    file: TextIOWrapper | None,
+    domain: str | None,
+    precision_mode: bool = False,
+) -> list[Domain]:
     """Read domains from file."""
 
     if domain is not None:
@@ -16,7 +20,7 @@ def read_domains(file: TextIOWrapper | None, domain: str | None, precision_mode:
         return []
 
     if file is None:
-        get_logger('io').critical('no input file specified, skipping reading domains..')
+        get_logger().warning('no input file specified, skipping reading domains..')
         return []
 
     urls: list[str] = list(set(file.read().splitlines()))
@@ -25,6 +29,6 @@ def read_domains(file: TextIOWrapper | None, domain: str | None, precision_mode:
         if (clean := transform_url_in_domain(url)) is not None:
             domains.append(Domain(clean, precision_mode))
 
-    get_logger('io').success(f'found { len(domains) } domains.')
+    get_logger().info(f'found { len(domains) } domains.')
 
     return domains
